var _ = require('lodash');
var colors = require('colors');

var objects = [];
var lengths = [];
var config = {};
var outputString = '';

function build(objects, config) {

    outputString = '';

    this.objects = objects;
    this.config = config;

    if(this.objects && this.objects.length != 0 && this.config) {

        buildLengths();
        orderData();
        buildOutputString();

    }

    return outputString;
}

function buildLengths() {

    _.each(this.config.columns, function(column) {

        var propertyLength = column.label.toString().length;

        if(!lengths[column.key] || propertyLength > lengths[column.key]) {

            lengths[column.key] = propertyLength;

        }
    });

    _.each(this.objects, function(object) {

        _.each(object, function(property, key) {

            var propertyLength = property.toString().length;

            if(!lengths[key] || propertyLength > lengths[key]) {

                lengths[key] = propertyLength;

            }
        });
    });
}

function orderData() {

  if(this.config.orderBy && !this.objects[0][this.config.orderBy]) {

    throw new Error("Property " + this.config.orderBy + " not found");
  }

  this.objects = _.sortBy(this.objects, this.config.orderBy);

}

function buildOutputString() {

    _.each(this.config.columns, function(column) {

        var lengthDifference = lengths[column.key] - column.label.length;

        outputString += column.label.bold;

        if(lengthDifference > 0) {

            outputString += Array(lengthDifference + 1).join(' ');

        }

        outputString += '   ';
    });

    outputString += '\n';

    _.each(this.objects, function(object) {

        _.each(this.config.columns, function(column) {

                var property = object[column.key];

                if(!property) {

                  throw new Error("Property " + column.key + " not found");
                }

                var lengthDifference = lengths[column.key] - property.length;

                if(column.style) {

                    var style = column.style(object);
                    outputString += style(property);

                } else {

                    outputString += property;

                }

                if(lengthDifference > 0) {

                    outputString += Array(lengthDifference + 1).join(' ');

                }

                outputString += '   ';

        });

        outputString += '\n';
    });
}

module.exports = build;
