var assert = require('assert');

var colors = require('colors');

var termtable = require('./termtable');

describe('termtable', function() {

  it('should return an empty string when objects are null and configs are null', function() {

    var table = termtable(null, null);
    assert.equal(table, '');
  });

  it('should return an empty string when objects are null', function() {

    var table = termtable([], null);
    assert.equal(table, '');
  });

  it('should return an empty string when configs are null', function() {

    var table = termtable(null, {});
    assert.equal(table, '');
  });

  it('should return an empty string when objects is an empty array and configs are an empty object', function() {

    var table = termtable([], {});
    assert.equal(table, '');
  });

  it('should return an empty string when objects is an empty array and configs are not empty', function() {

    var tableConfig = {
      columns: [
        {key: '_id', label: 'ID'},
        {key: 'title', label: 'Title'},
        {key: 'dueDate', label: 'Due Date'},
        {key: 'status', label: 'Status'}
      ]
    };

    var table = termtable([], tableConfig);
    assert.equal(table, '');
  });

  it('should return a table with a header and 2 rows', function() {

    var tableConfig = {
      columns: [
        {key: '1', label: '1'},
        {key: '2', label: '2'}
      ]
    };

    var data = [
      {1:'test1', 2:'test2'},
      {1:'test3', 2:'test4'}
    ];

    var table = termtable(data, tableConfig);
    assert.equal(table, '\u001b[1m1\u001b[22m       \u001b[1m2\u001b[22m       \ntest1   test2   \ntest3   test4   \n');
  });

  it('should order the data by parameter col1', function() {

    var tableConfig = {
      columns: [
        {key: 'col1', label: 'col1'},
        {key: 'col2', label: 'col2'}
      ],
      orderBy: 'col1'
    };

    var data = [
      {col1:'test3', col2:'test4'},
      {col1:'test1', col2:'test2'},
      {col1:'test2', col2:'test12'}
    ];

    var table = termtable(data, tableConfig);
    assert.equal(table, '\u001b[1mcol1\u001b[22m    \u001b[1mcol2\u001b[22m     \ntest1   test2    \ntest2   test12   \ntest3   test4    \n');
  });

  it('should throw an error if one of the columns doesn\'t exist', function() {

    var tableConfig = {
      columns: [
        {key: '1', label: '1'},
        {key: '2', label: '2'},
        {key: '3', label: '3'}
      ]
    };

    var data = [
      {1:'test1', 2:'test2'},
      {1:'test3', 2:'test4'}
    ];

    assert.throws(function(){

      termtable(data, tableConfig);
    }, Error, "Property 3 not found");
  });

  it('should throw an error if orderBy column doesn\'t exist', function() {

    var tableConfig = {
      columns: [
        {key: '1', label: '1'},
        {key: '2', label: '2'}
      ],
      orderBy: '5'
    };

    var data = [
      {1:'test1', 2:'test2'},
      {1:'test3', 2:'test4'}
    ];

    assert.throws(function(){

      termtable(data, tableConfig);
    }, Error, "Property 5 not found");
  });
});
